@@ -5,8 +5,6 @@ use Moose;
 use Example::Syntax;
 use Valiant::I18N; # Needed to load $HOME/locale
 
-__PACKAGE__->request_class_traits(['Catalyst::TraitFor::Request::ContentNegotiationHelpers']);
-
 __PACKAGE__->setup_plugins([qw/
   Session
   Session::State::Cookie
@@ -27,8 +25,11 @@ __PACKAGE__->config(
     traits => ['SchemaProxy'],
     schema_class => 'Example::Schema',
     connect_info => {
-      dsn => "dbi:SQLite:dbname=@{[ __PACKAGE__->path_to('var','db.db') ]}",
-    }
+      #dsn => "dbi:SQLite:dbname=@{[ __PACKAGE__->path_to('var','db.db') ]}",
+      dsn => "dbi:Pg:dbname=contacts;host=localhost;port=5432",
+      user => "contact_dbuser",
+      password => "abc123",
+    },
   },
 );
 
