@@ -6,20 +6,20 @@ use Example::Syntax;
 
 extends 'Example::Controller';
 
-sub root :Via('../public') At('register/...') ($self, $c, $user) {
+sub root :At('$path_end/...') Via('../public')  ($self, $c, $user) {
   return $c->redirect_to_action('/home/user_home') && $c->detach if $user->registered;
   $c->action->next($user);
 }
 
-  sub prepare_build :Via('root') At('...') ($self, $c, $user) {
+  sub prepare_build :At('...') Via('root') ($self, $c, $user) {
     $self->view_for('build', registration => $user); 
     $c->action->next($user);
   }
 
-    sub build :GET Via('prepare_build') At('new') ($self, $c, $user) { }
+    sub build :Get('new') Via('prepare_build') ($self, $c, $user) { }
 
-    sub create :POST Via('prepare_build') At('') BodyModel ($self, $c, $user, $request) {
-      return $user->register($request) ?
+    sub create :Post('') Via('prepare_build') BodyModel ($self, $c, $user, $bm) {
+      return $user->register($bm) ?
         $c->redirect_to_action('/session/build') :
           $c->view->set_http_bad_request;
     }
